{% extends "terminusgps_notifications/layout.html" %}
{% block content %}
<div class="flex flex-col gap-2">
    <p>You were logged out successfully.</p>
    <p>See you next time!</p>
</div>
{% endblock content %}
