# Generated by Django 5.2.9 on 2025-12-02 21:42

import django.core.validators
import terminusgps.wialon.flags
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('terminusgps_notifications', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='wialonnotification',
            name='name',
            field=models.CharField(help_text='Provide a memorable name.', max_length=64, validators=[django.core.validators.MinLengthValidator(4)]),
        ),
        migrations.AlterField(
            model_name='wialontoken',
            name='flags',
            field=models.PositiveIntegerField(default=terminusgps.wialon.flags.TokenFlag['ONLINE_TRACKING'] | terminusgps.wialon.flags.TokenFlag['VIEW_ACCESS'] | terminusgps.wialon.flags.TokenFlag['MANAGE_NONSENSITIVE'] | terminusgps.wialon.flags.TokenFlag['MANAGE_SENSITIVE']),
        ),
    ]
