<div class="p-4 flex flex-col gap-4 border-2 rounded bg-gray-50" hx-get="{% url 'terminusgps_notifications:subscription' %}" hx-target="#subscription" hx-select="#subscription" hx-swap="outerHTML" hx-trigger="load delay:3s">
    <div class="flex gap-2 items-center">
        <p class="text-lg">Thanks for subscribing!</p>
        <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="size-8">
          <path stroke-linecap="round" stroke-linejoin="round" d="M15.182 15.182a4.5 4.5 0 0 1-6.364 0M21 12a9 9 0 1 1-18 0 9 9 0 0 1 18 0ZM9.75 9.75c0 .414-.168.75-.375.75S9 10.164 9 9.75 9.168 9 9.375 9s.375.336.375.75Zm-.375 0h.008v.015h-.008V9.75Zm5.625 0c0 .414-.168.75-.375.75s-.375-.336-.375-.75.168-.75.375-.75.375.336.375.75Zm-.375 0h.008v.015h-.008V9.75Z" />
        </svg>
    </div>
    <p>Sending you back... <a href="{% url 'terminusgps_notifications:subscription' %}" hx-boost="true" class="w-fit decoration text-terminus-red-200 underline decoration-terminus-black underline-offset-4 hover:text-terminus-red-100 hover:decoration-dotted dark:decoration-white">Click here</a> if you aren't automatically redirected.</p>
</div>
