# Generated by Django 6.0 on 2025-12-16 16:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('terminusgps_notifications', '0002_alter_wialonnotification_name_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='wialonnotification',
            name='resource_name',
            field=models.CharField(blank=True, max_length=50),
        ),
    ]
